Flute-Reduced with Gravity
==========================

Flute-Reduced MHD - including gravity term instead of curvature. Basically the
same as Hazeltine-Meiss but different normalisations and have gravity intead of
curvature. Evolving Vorticity U, Parallel electric field Psi, Parallel velocity
Vpar, Pressure p, and density rho. Have included compressional terms in Vpar and
in pressure and density evolution equations.
